@@ -22,11 +22,11 @@ def _iter_internal_streams(input_streams, stream_type):
             streams.append(in_stream[1])
     for stream_value in streams:
         if isinstance(stream_value, output.ReturnCodeToSubunit):
-            if getattr(stream_value.source, 'detach', None):
+            if getattr(stream_value.source, "detach", None):
                 yield stream_value.source.detach()
             else:
                 yield stream_value.source
-        elif getattr(stream_value, 'read', None):
+        elif getattr(stream_value, "read", None):
             yield stream_value
         else:
             yield io.BytesIO(stream_value)
@@ -43,7 +43,7 @@ def iter_streams(input_streams, stream_type):
     """
     for stream_spec in input_streams:
         _stream_spec = stream_spec[0]
-        if '*' in _stream_spec or '?' in _stream_spec or '+' in _stream_spec:
+        if "*" in _stream_spec or "?" in _stream_spec or "+" in _stream_spec:
             found = stream_type == _stream_spec[:-1]
         else:
             found = stream_type == _stream_spec
@@ -63,19 +63,19 @@ def cleanup_test_name(name, strip_tags=True, strip_scenarios=False):
     identify generated negative tests.
     """
     if strip_tags:
-        tags_start = name.find('[')
-        tags_end = name.find(']')
+        tags_start = name.find("[")
+        tags_end = name.find("]")
         if tags_start > 0 and tags_end > tags_start:
             newname = name[:tags_start]
-            newname += name[tags_end + 1:]
+            newname += name[tags_end + 1 :]
             name = newname
 
     if strip_scenarios:
-        tags_start = name.find('(')
-        tags_end = name.find(')')
+        tags_start = name.find("(")
+        tags_end = name.find(")")
         if tags_start > 0 and tags_end > tags_start:
             newname = name[:tags_start]
-            newname += name[tags_end + 1:]
+            newname += name[tags_end + 1 :]
             name = newname
 
     return name
